@@ -1,8 +1,8 @@
 from pm4py.evaluation.replay_fitness.variants import alignment_based, token_replay
 from pm4py.algo.conformance import alignments
 from pm4py.objects.conversion.log import converter as log_conversion
-from pm4py.objects import petri
 from pm4py.util import exec_utils
+from pm4py.objects.petri.check_soundness import check_easy_soundness_net_in_fin_marking
 from enum import Enum
 
 
@@ -54,7 +54,7 @@ def apply(log, petri_net, initial_marking, final_marking, parameters=None, varia
     # execute the following part of code when the variant is not specified by the user
     if variant is None:
         if not (
-                petri.check_soundness.check_easy_soundness_net_in_fin_marking(petri_net, initial_marking,
+                check_easy_soundness_net_in_fin_marking(petri_net, initial_marking,
                                                                               final_marking)):
             # in the case the net is not a easy sound workflow net, we must apply token-based replay
             variant = TOKEN_BASED
