@@ -1,8 +1,6 @@
 import shutil
-import deprecation
 
-@deprecation.deprecated(deprecated_in='1.3.0', removed_in='2.0.0', current_version='',
-                        details='Use visualizer module instead.')
+
 def save(gviz, output_file_path):
     """
     Save the diagram
